# Generated by roxygen2: do not edit by hand

export(cal_length)
export(cal_node_limit)
export(cal_total_length)
export(dendsort)
export(sort_average)
export(sort_average_r)
export(sort_smallest)
export(sort_smallest_r)
importFrom(stats,as.dendrogram)
importFrom(stats,as.hclust)
importFrom(stats,is.leaf)
