[![Build Status](https://travis-ci.com/evanbiederstedt/dendsort.svg?branch=main)](https://travis-ci.com/github/evanbiederstedt/dendsort)
[![CRAN status](https://www.r-pkg.org/badges/version/dendsort)](https://cran.r-project.org/package=dendsort)
[![CRAN downloads](https://cranlogs.r-pkg.org/badges/dendsort)](https://cran.r-project.org/package=dendsort)


# dendsort

## Modular Leaf Ordering Methods for Dendrogram Nodes

More information on this package can be found on CRAN [here](https://cran.r-project.org/package=dendsort).

This is a forked repo from dendsort version 0.3.3, which were made given updates to CRAN dependencies. The original sourcecode by the author Ryo Sakai can be found on Bitbucket [here](https://bitbucket.org/vda-lab/dendsort/wiki/Home). The only changes made to this version were related to the vignettes. 

### Vignettes

* HTML version
* Markdown version

### Citation

For more information on the method, please the F1000 article [here](https://f1000research.com/articles/3-177/v1):

```
Sakai R, Winand R, Verbeiren T et al. 
dendsort: modular leaf ordering methods for dendrogram representations in R.
F1000Research 2014, 3:177 (https://doi.org/10.12688/f1000research.4784.1)
```
